# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/nbsqueeze',
                'doc_host': 'https://fligt.github.io',
                'git_url': 'https://github.com/fligt/nbsqueeze',
                'lib_path': 'nbsqueeze'},
  'syms': { 'nbsqueeze.extract': { 'nbsqueeze.extract.export_pngs': ('extract.html#export_pngs', 'nbsqueeze/extract.py'),
                                   'nbsqueeze.extract.find_png_strings': ('extract.html#find_png_strings', 'nbsqueeze/extract.py'),
                                   'nbsqueeze.extract.make_imdir': ('extract.html#make_imdir', 'nbsqueeze/extract.py'),
                                   'nbsqueeze.extract.replace_strings': ('extract.html#replace_strings', 'nbsqueeze/extract.py'),
                                   'nbsqueeze.extract.squeeze_this_nb': ('extract.html#squeeze_this_nb', 'nbsqueeze/extract.py')},
            'nbsqueeze.squeeze': { 'nbsqueeze.squeeze.clean_imdir': ('console-command.html#clean_imdir', 'nbsqueeze/squeeze.py'),
                                   'nbsqueeze.squeeze.find_links': ('console-command.html#find_links', 'nbsqueeze/squeeze.py'),
                                   'nbsqueeze.squeeze.squeeze': ('console-command.html#squeeze', 'nbsqueeze/squeeze.py')}}}
